
$ (WhseRfg0.inc)

$ ---------------------------- MISC PARAMETERS --------------------------------

PARAMETER

   FreezerT      -10  $ Freezer temperature
   FreezerDT       5  $ dT between supply and space
   MeatDeliT      30  $ Meat/Deli temperature
   MeatDeliDT      5  
   ProduceT       40  $ Produce temperature
   ProduceDT       5  
   DockT          45  $ Dock temperature
   DockDT          5  

..

$ ---------------------------- EEM SETUP --------------------------------------

$ Show the details of the macro evaluation logic in the expansion
##showdetail    

$ File "for022" shows a clean BDL input file after evaluating all macros
##write        

$ This include file requires the following Macros be set prior to calling
$ this file.  

$ ##set1 Vintage        1  <1978
$                       2  1978-1992
$                       3  1993-2001
$                       4  2002-2005
$                       5  >2005 existing - HVAC cannot be downsized
$                       6  >2005 new - HVAC can be downsized

$ ##set1 DesignWB      70  The design wetbulb for the climate zone

$ ##set1 RunMode RunBase  The base case run
$                RunT24   The minimally-compliant T24 configuration
$                RunEEM   The run incorporating the EEM
$

$ ##set1 EEM1  NoEEM  No EEM; runs just the default base case
$ -- 1994 DEER EEMs
$              4B  Floating head pressure, fixed setpoint - evap cooled
$              5B  Floating head pressure, variable setpoint - evap cooled
$              6B  Floating head pressure, variable setpoint
$                    and variable speed - evap cooled
$              63A Oversized condenser, with higher specific efficiency
$              63B Oversized condenser, plus 6B
$              74  Replace compressor slide valves with VFD
$               
$ -- Other potential EEMs
$              61  Extensive Refrigeration Equipment Maintenance


$ -- Savings By Design EEMs
$               8  Low temp mechanical subcooling
$               9  Floating suction pressure


$ Define the standard BASE CASE.  Depending on the EEM, the EEM will change
$ the base case as needed.

##set1 CompressorCtrl SlideValve  $ SlideValve, VarSpeed
##set1 CondEff        Base        $ Base, T24, HiEff
##set1 CondFanCtrl    CYCLE-FAN   $ CYCLE-FAN, TWO-SPEED-FAN, VAR-SPEED-FAN
##set1 CondHeadCtrl   Fixed       $ Fixed, Ambient, DrybulbStaged
##set1 NeedsMaint     No          $ No, Yes

##set1 SuctionCtrl    Fixed       $ Fixed, Float

$ -- Base case, vintage dependent

##if #[Vintage[] EQ 1]
  ##set1 SCTsetpt       90          $ Condensing temperature setpoint
  ##set1 SubcoolerLT    No          $ No, Yes

##elseif #[Vintage[] EQ 2]
  ##set1 SCTsetpt       90           
  ##set1 SubcoolerLT    No 

##elseif #[Vintage[] EQ 3]
  ##set1 SCTsetpt       90           
  ##set1 SubcoolerLT    No 

##elseif #[Vintage[] EQ 4]
  ##set1 SCTsetpt       85           
  ##set1 SubcoolerLT    No 

##elseif #[Vintage[] EQ 5]
  ##set1 SCTsetpt       85           
  ##set1 SubcoolerLT    Yes 

##elseif #[Vintage[] EQ 6]
  ##set1 SCTsetpt       85           
  ##set1 SubcoolerLT    Yes 

##else
  ERROR - Invalid Age Category - Vintage[]
##endif



$ This macro turns on a specific EEM (or package of EEMs), using one or more
$ of the parameters defined above.  This algorithm may be called multiple
$ times for multiple EEMs, as long as the EEMs are compatible with each other,
$ and the base-case generated by a particular EEM is compatible with the
$ needs of the others.

##def SetUpEEM[ EEMx ]
  ##if #[EEMx EQS NoEEM]   $ No EEM; run default base case

  ##elseif #[EEMx EQS 4B]  $ Floating head pressure, fixed setpoint
                           $  - evap cooled
    ##if #[RunMode[] EQS RunT24]
      ##set1 SCTsetpt      85
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 SCTsetpt      70           
    ##endif

  ##elseif #[EEMx EQS 5B]  $ Floating head pressure, variable setpoint
    ##if #[RunMode[] EQS RunT24]
      ##set1 SCTsetpt      85
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 CondHeadCtrl  Ambient
    ##endif

  ##elseif #[EEMx EQS 6B]  $ Floating head pressure, variable setpoint
                           $ and variable speed - evap cooled
    ##if #[RunMode[] EQS RunT24]
      ##set1 SCTsetpt      85
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 CondHeadCtrl  Ambient
      ##set1 CondFanCtrl   VAR-SPEED-FAN
    ##endif

  ##elseif #[EEMx EQS 8]   $ Low temp mechanical subcooling
    ##if #[RunMode[] EQS RunT24]
      ##set1 SubcoolerLT  Yes
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 SubcoolerLT  Yes
    ##endif

  ##elseif #[EEMx EQS 9]   $ Floating suction pressure
    ##if #[RunMode[] EQS RunEEM]
      ##set1 SuctionCtrl  Float
    ##endif

  ##elseif #[EEMx EQS 61]  $ Extensive Refrigeration Equipment Maintenance
    ##if #[RunMode[] EQS RunBase]
      ##if #[Vintage[] LT 5]
        ##set1 NeedsMaint  Yes
      ##endif
    ##endif

  ##elseif #[EEMx EQS 63A]  $ Energy efficient evap-cooled condenser
    ##if #[RunMode[] EQS RunT24]
      ##set1 CondEff       T24
      ##set1 SCTsetpt      85
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 CondEff       HiEff
      ##set1 SCTsetpt      85
    ##endif

  ##elseif #[EEMx EQS 63B]  $ Energy efficient evap-cooled condenser, 
                            $ VFD, ambient head ctrl (6B)
    ##if #[RunMode[] EQS RunT24]
      ##set1 CondEff  T24
    ##elseif #[RunMode[] EQS RunEEM]
      ##set1 CondEff       HiEff
      ##set1 CondHeadCtrl  Ambient
      ##set1 CondFanCtrl   VAR-SPEED-FAN
    ##endif

  ##elseif #[EEMx EQS 74]  $ Compressor VFD
    ##if #[RunMode[] EQS RunEEM]
      ##set1 CompressorCtrl VarSpeed
    ##endif

  ##else                   $ Invalid EEM if here
    ERROR - Invalid EEM name - EEMx
  ##endif
##enddef  $ SetUpEEM

$ Now turn on the EEMs, up to 5 total

##ifdef EEM1[]
  SetUpEEM[ EEM1[] ]
##else
  ERROR - No EEM defined
##endif
##ifdef EEM2[]
  SetUpEEM[ EEM2[] ]
##endif
##ifdef EEM3[]
  SetUpEEM[ EEM3[] ]
##endif
##ifdef EEM4[]
  SetUpEEM[ EEM4[] ]
##endif
##ifdef EEM5[]
  SetUpEEM[ EEM5[] ]
##endif


$ Macros to simplify EEM generation in refrigeration equipment

##def CompressorPLR[CurveSlide, CurveVFD]
  ##if #[CompressorCtrl[] EQS SlideValve]
    $PWR-FPLR         $ CurveSlide
  ##elseif #[CompressorCtrl[] EQS VarSpeed]
    $PWR-FPLR         $ CurveVFD
  ##else
    ERROR - Invalid CompressorCtrl
  ##endif
##enddef

$ Design EIR for evap condenser; 75/25 split between fan and pump
##def EvapCondCap&EIR[CondCap]
   $RATED-CAPACITY  $ CondCap

  ##if #[CondEff[] EQS Base]
    ##if #[ #[Vintage[] EQ 1] OR #[Vintage[] EQ 2] ]
      FAN-EIR         = #[#[3.413 / 200] * 0.75]      
      SPRAY-EIR       = #[#[3.413 / 200] * 0.25]
      RATED-SCT       = 100
      RATED-WETBULB   = 72
    ##elseif #[Vintage[] EQ 3]
      FAN-EIR         = #[#[3.413 / 200] * 0.75]      
      SPRAY-EIR       = #[#[3.413 / 200] * 0.25]
      RATED-SCT       = 97
      RATED-WETBULB   = 72
    ##elseif #[Vintage[] EQ 4]
      FAN-EIR         = #[#[3.413 / 275] * 0.75]      
      SPRAY-EIR       = #[#[3.413 / 275] * 0.25]
      RATED-SCT       = 95
      RATED-WETBULB   = 72
    ##else
      FAN-EIR         = #[#[3.413 / 330] * 0.75]      
      SPRAY-EIR       = #[#[3.413 / 330] * 0.25]
      RATED-SCT       = 95
      RATED-WETBULB   = 72
    ##endif
  ##elseif #[CondEff[] EQS T24]
      FAN-EIR         = #[#[3.413 / 330] * 0.75]      
      SPRAY-EIR       = #[#[3.413 / 330] * 0.25]
      RATED-SCT       = 95
      RATED-WETBULB   = 72
  ##elseif #[CondEff[] EQS HiEff]
     FAN-EIR          = #[#[3.413 / 400] * 0.75]      
     SPRAY-EIR        = #[#[3.413 / 400] * 0.25]
     RATED-SCT        = #[60.8 + #[DesignWB[] * 0.4]]
     RATED-WETBULB    = DesignWB[]
  ##else
    ERROR - Invalid CondEff
  ##endif
     EIR-RATED-WB     = 70
     EIR-RATED-SCT    = 100
##enddef

$ Condenser temperature control
##def SCTctrl[]
  ##if #[CondHeadCtrl[] EQS Fixed]
   $SCT-CTRL         $ FIXED
    ##if #[NeedsMaint[] EQS No]
      SCT-SETPT      = SCTsetpt[]
    ##elseif #[NeedsMaint[] EQS Yes]
      SCT-SETPT      = #[SCTsetpt[] + 2.]
    ##else
      ERROR - Invalid NeedsMaint
    ##endif
    BACKFLOOD-SETPT  = #[SCTsetpt[] - 2.]
  ##elseif #[CondHeadCtrl[] EQS Ambient]
   $SCT-CTRL         $ WETBULB-RESET
    SCT-AMBIENT-DT   = 9  
    OVERRIDE-MIN-SCT = 70
    BACKFLOOD-SETPT  = 68
  ##else
    ERROR - Invalid CondHeadCtrl
  ##endif
  SCT-THROTTLE   = 1
  BACKFLOOD-CTRL = FIXED
##enddef

$ Suction-group temperature control
$ Fixed suction setpoint is set 3F + 1/2 throttle below design point
$ to approximate a conservative mechanical setting
##def SuctionTempCtrl[DesSST, Throttle]
  ##if #[SuctionCtrl[] EQS Fixed]
   $TEMP-CTRL        $ FIXED
    ##if #[NeedsMaint[] EQS No]
      TEMP-SETPT     = #[DesSST - #[3. + #[Throttle * 0.5]]]
    ##elseif #[NeedsMaint[] EQS Yes]
      TEMP-SETPT     = #[DesSST - #[6. + #[Throttle * 0.5]]]
    ##else
      ERROR - Invalid NeedsMaint
    ##endif
  ##elseif #[SuctionCtrl[] EQS Float]
   $TEMP-CTRL        $ LOAD-RESET
    MAX-TEMP-SETPT   = #[DesSST + 5]
    MIN-TEMP-SETPT   = #[DesSST - #[3. + #[Throttle * 0.5]]]
  ##else
    ERROR - Invalid SuctionCtrl
  ##endif
    DESIGN-SST       = DesSST
    TEMP-THROTTLE    = Throttle
##enddef


$ SAC 5/18/05 - Added WINDOW SET-DEFAULTs to ensure C- daylighting keywords are valid 
SET-DEFAULT FOR WINDOW
   C-WELL-HEIGHT    = {#L("HEIGHT")}
   C-WELL-WIDTH     = {#L("WIDTH")}
   C-WELL-WALL-REFL = 0.5
   C-WELL-TOP-REFL  = 0.75
   C-WELL-DEPTH     = {
      if (#RV(#P3("FLOOR-HEIGHT"))!=0 .OR. #RV(#P2("HEIGHT"))!=0) then  0.5
      else if (#P3("FLOOR-HEIGHT") - #P2("HEIGHT") >= 0.5) then
               #P3("FLOOR-HEIGHT") - #P2("HEIGHT")
      else  0.5
      endif endif}
..
